/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ApphubWorkloadConfig extends cdktf.TerraformMetaArguments {
    /**
    * Part of 'parent'.  Full resource name of a parent Application. Example: projects/{HOST_PROJECT_ID}/locations/{LOCATION}/applications/{APPLICATION_ID}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#application_id ApphubWorkload#application_id}
    */
    readonly applicationId: string;
    /**
    * User-defined description of a Workload.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#description ApphubWorkload#description}
    */
    readonly description?: string;
    /**
    * Immutable. The resource name of the original discovered workload.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#discovered_workload ApphubWorkload#discovered_workload}
    */
    readonly discoveredWorkload: string;
    /**
    * User-defined name for the Workload.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#display_name ApphubWorkload#display_name}
    */
    readonly displayName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#id ApphubWorkload#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Part of 'parent'.  Full resource name of a parent Application. Example: projects/{HOST_PROJECT_ID}/locations/{LOCATION}/applications/{APPLICATION_ID}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#location ApphubWorkload#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#project ApphubWorkload#project}
    */
    readonly project?: string;
    /**
    * The Workload identifier.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#workload_id ApphubWorkload#workload_id}
    */
    readonly workloadId: string;
    /**
    * attributes block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#attributes ApphubWorkload#attributes}
    */
    readonly attributes?: ApphubWorkloadAttributes;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#timeouts ApphubWorkload#timeouts}
    */
    readonly timeouts?: ApphubWorkloadTimeouts;
}
export interface ApphubWorkloadWorkloadProperties {
}
export declare function apphubWorkloadWorkloadPropertiesToTerraform(struct?: ApphubWorkloadWorkloadProperties): any;
export declare function apphubWorkloadWorkloadPropertiesToHclTerraform(struct?: ApphubWorkloadWorkloadProperties): any;
export declare class ApphubWorkloadWorkloadPropertiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ApphubWorkloadWorkloadProperties | undefined;
    set internalValue(value: ApphubWorkloadWorkloadProperties | undefined);
    get gcpProject(): string;
    get location(): string;
    get zone(): string;
}
export declare class ApphubWorkloadWorkloadPropertiesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ApphubWorkloadWorkloadPropertiesOutputReference;
}
export interface ApphubWorkloadWorkloadReference {
}
export declare function apphubWorkloadWorkloadReferenceToTerraform(struct?: ApphubWorkloadWorkloadReference): any;
export declare function apphubWorkloadWorkloadReferenceToHclTerraform(struct?: ApphubWorkloadWorkloadReference): any;
export declare class ApphubWorkloadWorkloadReferenceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ApphubWorkloadWorkloadReference | undefined;
    set internalValue(value: ApphubWorkloadWorkloadReference | undefined);
    get uri(): string;
}
export declare class ApphubWorkloadWorkloadReferenceList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ApphubWorkloadWorkloadReferenceOutputReference;
}
export interface ApphubWorkloadAttributesBusinessOwners {
    /**
    * Contact's name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#display_name ApphubWorkload#display_name}
    */
    readonly displayName?: string;
    /**
    * Email address of the contacts.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#email ApphubWorkload#email}
    */
    readonly email: string;
}
export declare function apphubWorkloadAttributesBusinessOwnersToTerraform(struct?: ApphubWorkloadAttributesBusinessOwners | cdktf.IResolvable): any;
export declare function apphubWorkloadAttributesBusinessOwnersToHclTerraform(struct?: ApphubWorkloadAttributesBusinessOwners | cdktf.IResolvable): any;
export declare class ApphubWorkloadAttributesBusinessOwnersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ApphubWorkloadAttributesBusinessOwners | cdktf.IResolvable | undefined;
    set internalValue(value: ApphubWorkloadAttributesBusinessOwners | cdktf.IResolvable | undefined);
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _email?;
    get email(): string;
    set email(value: string);
    get emailInput(): string | undefined;
}
export declare class ApphubWorkloadAttributesBusinessOwnersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ApphubWorkloadAttributesBusinessOwners[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ApphubWorkloadAttributesBusinessOwnersOutputReference;
}
export interface ApphubWorkloadAttributesCriticality {
    /**
    * Criticality type. Possible values: ["MISSION_CRITICAL", "HIGH", "MEDIUM", "LOW"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#type ApphubWorkload#type}
    */
    readonly type: string;
}
export declare function apphubWorkloadAttributesCriticalityToTerraform(struct?: ApphubWorkloadAttributesCriticalityOutputReference | ApphubWorkloadAttributesCriticality): any;
export declare function apphubWorkloadAttributesCriticalityToHclTerraform(struct?: ApphubWorkloadAttributesCriticalityOutputReference | ApphubWorkloadAttributesCriticality): any;
export declare class ApphubWorkloadAttributesCriticalityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ApphubWorkloadAttributesCriticality | undefined;
    set internalValue(value: ApphubWorkloadAttributesCriticality | undefined);
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
}
export interface ApphubWorkloadAttributesDeveloperOwners {
    /**
    * Contact's name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#display_name ApphubWorkload#display_name}
    */
    readonly displayName?: string;
    /**
    * Email address of the contacts.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#email ApphubWorkload#email}
    */
    readonly email: string;
}
export declare function apphubWorkloadAttributesDeveloperOwnersToTerraform(struct?: ApphubWorkloadAttributesDeveloperOwners | cdktf.IResolvable): any;
export declare function apphubWorkloadAttributesDeveloperOwnersToHclTerraform(struct?: ApphubWorkloadAttributesDeveloperOwners | cdktf.IResolvable): any;
export declare class ApphubWorkloadAttributesDeveloperOwnersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ApphubWorkloadAttributesDeveloperOwners | cdktf.IResolvable | undefined;
    set internalValue(value: ApphubWorkloadAttributesDeveloperOwners | cdktf.IResolvable | undefined);
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _email?;
    get email(): string;
    set email(value: string);
    get emailInput(): string | undefined;
}
export declare class ApphubWorkloadAttributesDeveloperOwnersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ApphubWorkloadAttributesDeveloperOwners[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ApphubWorkloadAttributesDeveloperOwnersOutputReference;
}
export interface ApphubWorkloadAttributesEnvironment {
    /**
    * Environment type. Possible values: ["PRODUCTION", "STAGING", "TEST", "DEVELOPMENT"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#type ApphubWorkload#type}
    */
    readonly type: string;
}
export declare function apphubWorkloadAttributesEnvironmentToTerraform(struct?: ApphubWorkloadAttributesEnvironmentOutputReference | ApphubWorkloadAttributesEnvironment): any;
export declare function apphubWorkloadAttributesEnvironmentToHclTerraform(struct?: ApphubWorkloadAttributesEnvironmentOutputReference | ApphubWorkloadAttributesEnvironment): any;
export declare class ApphubWorkloadAttributesEnvironmentOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ApphubWorkloadAttributesEnvironment | undefined;
    set internalValue(value: ApphubWorkloadAttributesEnvironment | undefined);
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
}
export interface ApphubWorkloadAttributesOperatorOwners {
    /**
    * Contact's name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#display_name ApphubWorkload#display_name}
    */
    readonly displayName?: string;
    /**
    * Email address of the contacts.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#email ApphubWorkload#email}
    */
    readonly email: string;
}
export declare function apphubWorkloadAttributesOperatorOwnersToTerraform(struct?: ApphubWorkloadAttributesOperatorOwners | cdktf.IResolvable): any;
export declare function apphubWorkloadAttributesOperatorOwnersToHclTerraform(struct?: ApphubWorkloadAttributesOperatorOwners | cdktf.IResolvable): any;
export declare class ApphubWorkloadAttributesOperatorOwnersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ApphubWorkloadAttributesOperatorOwners | cdktf.IResolvable | undefined;
    set internalValue(value: ApphubWorkloadAttributesOperatorOwners | cdktf.IResolvable | undefined);
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _email?;
    get email(): string;
    set email(value: string);
    get emailInput(): string | undefined;
}
export declare class ApphubWorkloadAttributesOperatorOwnersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ApphubWorkloadAttributesOperatorOwners[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ApphubWorkloadAttributesOperatorOwnersOutputReference;
}
export interface ApphubWorkloadAttributes {
    /**
    * business_owners block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#business_owners ApphubWorkload#business_owners}
    */
    readonly businessOwners?: ApphubWorkloadAttributesBusinessOwners[] | cdktf.IResolvable;
    /**
    * criticality block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#criticality ApphubWorkload#criticality}
    */
    readonly criticality?: ApphubWorkloadAttributesCriticality;
    /**
    * developer_owners block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#developer_owners ApphubWorkload#developer_owners}
    */
    readonly developerOwners?: ApphubWorkloadAttributesDeveloperOwners[] | cdktf.IResolvable;
    /**
    * environment block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#environment ApphubWorkload#environment}
    */
    readonly environment?: ApphubWorkloadAttributesEnvironment;
    /**
    * operator_owners block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#operator_owners ApphubWorkload#operator_owners}
    */
    readonly operatorOwners?: ApphubWorkloadAttributesOperatorOwners[] | cdktf.IResolvable;
}
export declare function apphubWorkloadAttributesToTerraform(struct?: ApphubWorkloadAttributesOutputReference | ApphubWorkloadAttributes): any;
export declare function apphubWorkloadAttributesToHclTerraform(struct?: ApphubWorkloadAttributesOutputReference | ApphubWorkloadAttributes): any;
export declare class ApphubWorkloadAttributesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ApphubWorkloadAttributes | undefined;
    set internalValue(value: ApphubWorkloadAttributes | undefined);
    private _businessOwners;
    get businessOwners(): ApphubWorkloadAttributesBusinessOwnersList;
    putBusinessOwners(value: ApphubWorkloadAttributesBusinessOwners[] | cdktf.IResolvable): void;
    resetBusinessOwners(): void;
    get businessOwnersInput(): cdktf.IResolvable | ApphubWorkloadAttributesBusinessOwners[] | undefined;
    private _criticality;
    get criticality(): ApphubWorkloadAttributesCriticalityOutputReference;
    putCriticality(value: ApphubWorkloadAttributesCriticality): void;
    resetCriticality(): void;
    get criticalityInput(): ApphubWorkloadAttributesCriticality | undefined;
    private _developerOwners;
    get developerOwners(): ApphubWorkloadAttributesDeveloperOwnersList;
    putDeveloperOwners(value: ApphubWorkloadAttributesDeveloperOwners[] | cdktf.IResolvable): void;
    resetDeveloperOwners(): void;
    get developerOwnersInput(): cdktf.IResolvable | ApphubWorkloadAttributesDeveloperOwners[] | undefined;
    private _environment;
    get environment(): ApphubWorkloadAttributesEnvironmentOutputReference;
    putEnvironment(value: ApphubWorkloadAttributesEnvironment): void;
    resetEnvironment(): void;
    get environmentInput(): ApphubWorkloadAttributesEnvironment | undefined;
    private _operatorOwners;
    get operatorOwners(): ApphubWorkloadAttributesOperatorOwnersList;
    putOperatorOwners(value: ApphubWorkloadAttributesOperatorOwners[] | cdktf.IResolvable): void;
    resetOperatorOwners(): void;
    get operatorOwnersInput(): cdktf.IResolvable | ApphubWorkloadAttributesOperatorOwners[] | undefined;
}
export interface ApphubWorkloadTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#create ApphubWorkload#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#delete ApphubWorkload#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#update ApphubWorkload#update}
    */
    readonly update?: string;
}
export declare function apphubWorkloadTimeoutsToTerraform(struct?: ApphubWorkloadTimeouts | cdktf.IResolvable): any;
export declare function apphubWorkloadTimeoutsToHclTerraform(struct?: ApphubWorkloadTimeouts | cdktf.IResolvable): any;
export declare class ApphubWorkloadTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): ApphubWorkloadTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: ApphubWorkloadTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload google_apphub_workload}
*/
export declare class ApphubWorkload extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_apphub_workload";
    /**
    * Generates CDKTF code for importing a ApphubWorkload resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ApphubWorkload to import
    * @param importFromId The id of the existing ApphubWorkload that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ApphubWorkload to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/apphub_workload google_apphub_workload} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ApphubWorkloadConfig
    */
    constructor(scope: Construct, id: string, config: ApphubWorkloadConfig);
    private _applicationId?;
    get applicationId(): string;
    set applicationId(value: string);
    get applicationIdInput(): string | undefined;
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _discoveredWorkload?;
    get discoveredWorkload(): string;
    set discoveredWorkload(value: string);
    get discoveredWorkloadInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get state(): string;
    get uid(): string;
    get updateTime(): string;
    private _workloadId?;
    get workloadId(): string;
    set workloadId(value: string);
    get workloadIdInput(): string | undefined;
    private _workloadProperties;
    get workloadProperties(): ApphubWorkloadWorkloadPropertiesList;
    private _workloadReference;
    get workloadReference(): ApphubWorkloadWorkloadReferenceList;
    private _attributes;
    get attributes(): ApphubWorkloadAttributesOutputReference;
    putAttributes(value: ApphubWorkloadAttributes): void;
    resetAttributes(): void;
    get attributesInput(): ApphubWorkloadAttributes | undefined;
    private _timeouts;
    get timeouts(): ApphubWorkloadTimeoutsOutputReference;
    putTimeouts(value: ApphubWorkloadTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | ApphubWorkloadTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
