/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GkeHubFleetConfig extends cdktf.TerraformMetaArguments {
    /**
    * A user-assigned display name of the Fleet. When present, it must be between 4 to 30 characters.
    * Allowed characters are: lowercase and uppercase letters, numbers, hyphen, single-quote, double-quote, space, and exclamation point.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/gke_hub_fleet#display_name GkeHubFleet#display_name}
    */
    readonly displayName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/gke_hub_fleet#id GkeHubFleet#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/gke_hub_fleet#project GkeHubFleet#project}
    */
    readonly project?: string;
    /**
    * default_cluster_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/gke_hub_fleet#default_cluster_config GkeHubFleet#default_cluster_config}
    */
    readonly defaultClusterConfig?: GkeHubFleetDefaultClusterConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/gke_hub_fleet#timeouts GkeHubFleet#timeouts}
    */
    readonly timeouts?: GkeHubFleetTimeouts;
}
export interface GkeHubFleetState {
}
export declare function gkeHubFleetStateToTerraform(struct?: GkeHubFleetState): any;
export declare function gkeHubFleetStateToHclTerraform(struct?: GkeHubFleetState): any;
export declare class GkeHubFleetStateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GkeHubFleetState | undefined;
    set internalValue(value: GkeHubFleetState | undefined);
    get code(): string;
}
export declare class GkeHubFleetStateList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GkeHubFleetStateOutputReference;
}
export interface GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfigPolicyBindings {
    /**
    * The relative resource name of the binauthz platform policy to audit. GKE
    * platform policies have the following format:
    * 'projects/{project_number}/platforms/gke/policies/{policy_id}'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/gke_hub_fleet#name GkeHubFleet#name}
    */
    readonly name?: string;
}
export declare function gkeHubFleetDefaultClusterConfigBinaryAuthorizationConfigPolicyBindingsToTerraform(struct?: GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfigPolicyBindings | cdktf.IResolvable): any;
export declare function gkeHubFleetDefaultClusterConfigBinaryAuthorizationConfigPolicyBindingsToHclTerraform(struct?: GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfigPolicyBindings | cdktf.IResolvable): any;
export declare class GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfigPolicyBindingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfigPolicyBindings | cdktf.IResolvable | undefined;
    set internalValue(value: GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfigPolicyBindings | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
}
export declare class GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfigPolicyBindingsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfigPolicyBindings[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfigPolicyBindingsOutputReference;
}
export interface GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfig {
    /**
    * Mode of operation for binauthz policy evaluation. Possible values: ["DISABLED", "POLICY_BINDINGS"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/gke_hub_fleet#evaluation_mode GkeHubFleet#evaluation_mode}
    */
    readonly evaluationMode?: string;
    /**
    * policy_bindings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/gke_hub_fleet#policy_bindings GkeHubFleet#policy_bindings}
    */
    readonly policyBindings?: GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfigPolicyBindings[] | cdktf.IResolvable;
}
export declare function gkeHubFleetDefaultClusterConfigBinaryAuthorizationConfigToTerraform(struct?: GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfigOutputReference | GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfig): any;
export declare function gkeHubFleetDefaultClusterConfigBinaryAuthorizationConfigToHclTerraform(struct?: GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfigOutputReference | GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfig): any;
export declare class GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfig | undefined;
    set internalValue(value: GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfig | undefined);
    private _evaluationMode?;
    get evaluationMode(): string;
    set evaluationMode(value: string);
    resetEvaluationMode(): void;
    get evaluationModeInput(): string | undefined;
    private _policyBindings;
    get policyBindings(): GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfigPolicyBindingsList;
    putPolicyBindings(value: GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfigPolicyBindings[] | cdktf.IResolvable): void;
    resetPolicyBindings(): void;
    get policyBindingsInput(): cdktf.IResolvable | GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfigPolicyBindings[] | undefined;
}
export interface GkeHubFleetDefaultClusterConfigSecurityPostureConfig {
    /**
    * Sets which mode to use for Security Posture features. Possible values: ["DISABLED", "BASIC"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/gke_hub_fleet#mode GkeHubFleet#mode}
    */
    readonly mode?: string;
    /**
    * Sets which mode to use for vulnerability scanning. Possible values: ["VULNERABILITY_DISABLED", "VULNERABILITY_BASIC", "VULNERABILITY_ENTERPRISE"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/gke_hub_fleet#vulnerability_mode GkeHubFleet#vulnerability_mode}
    */
    readonly vulnerabilityMode?: string;
}
export declare function gkeHubFleetDefaultClusterConfigSecurityPostureConfigToTerraform(struct?: GkeHubFleetDefaultClusterConfigSecurityPostureConfigOutputReference | GkeHubFleetDefaultClusterConfigSecurityPostureConfig): any;
export declare function gkeHubFleetDefaultClusterConfigSecurityPostureConfigToHclTerraform(struct?: GkeHubFleetDefaultClusterConfigSecurityPostureConfigOutputReference | GkeHubFleetDefaultClusterConfigSecurityPostureConfig): any;
export declare class GkeHubFleetDefaultClusterConfigSecurityPostureConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GkeHubFleetDefaultClusterConfigSecurityPostureConfig | undefined;
    set internalValue(value: GkeHubFleetDefaultClusterConfigSecurityPostureConfig | undefined);
    private _mode?;
    get mode(): string;
    set mode(value: string);
    resetMode(): void;
    get modeInput(): string | undefined;
    private _vulnerabilityMode?;
    get vulnerabilityMode(): string;
    set vulnerabilityMode(value: string);
    resetVulnerabilityMode(): void;
    get vulnerabilityModeInput(): string | undefined;
}
export interface GkeHubFleetDefaultClusterConfig {
    /**
    * binary_authorization_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/gke_hub_fleet#binary_authorization_config GkeHubFleet#binary_authorization_config}
    */
    readonly binaryAuthorizationConfig?: GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfig;
    /**
    * security_posture_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/gke_hub_fleet#security_posture_config GkeHubFleet#security_posture_config}
    */
    readonly securityPostureConfig?: GkeHubFleetDefaultClusterConfigSecurityPostureConfig;
}
export declare function gkeHubFleetDefaultClusterConfigToTerraform(struct?: GkeHubFleetDefaultClusterConfigOutputReference | GkeHubFleetDefaultClusterConfig): any;
export declare function gkeHubFleetDefaultClusterConfigToHclTerraform(struct?: GkeHubFleetDefaultClusterConfigOutputReference | GkeHubFleetDefaultClusterConfig): any;
export declare class GkeHubFleetDefaultClusterConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GkeHubFleetDefaultClusterConfig | undefined;
    set internalValue(value: GkeHubFleetDefaultClusterConfig | undefined);
    private _binaryAuthorizationConfig;
    get binaryAuthorizationConfig(): GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfigOutputReference;
    putBinaryAuthorizationConfig(value: GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfig): void;
    resetBinaryAuthorizationConfig(): void;
    get binaryAuthorizationConfigInput(): GkeHubFleetDefaultClusterConfigBinaryAuthorizationConfig | undefined;
    private _securityPostureConfig;
    get securityPostureConfig(): GkeHubFleetDefaultClusterConfigSecurityPostureConfigOutputReference;
    putSecurityPostureConfig(value: GkeHubFleetDefaultClusterConfigSecurityPostureConfig): void;
    resetSecurityPostureConfig(): void;
    get securityPostureConfigInput(): GkeHubFleetDefaultClusterConfigSecurityPostureConfig | undefined;
}
export interface GkeHubFleetTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/gke_hub_fleet#create GkeHubFleet#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/gke_hub_fleet#delete GkeHubFleet#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/gke_hub_fleet#update GkeHubFleet#update}
    */
    readonly update?: string;
}
export declare function gkeHubFleetTimeoutsToTerraform(struct?: GkeHubFleetTimeouts | cdktf.IResolvable): any;
export declare function gkeHubFleetTimeoutsToHclTerraform(struct?: GkeHubFleetTimeouts | cdktf.IResolvable): any;
export declare class GkeHubFleetTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GkeHubFleetTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GkeHubFleetTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/gke_hub_fleet google_gke_hub_fleet}
*/
export declare class GkeHubFleet extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_gke_hub_fleet";
    /**
    * Generates CDKTF code for importing a GkeHubFleet resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GkeHubFleet to import
    * @param importFromId The id of the existing GkeHubFleet that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/gke_hub_fleet#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GkeHubFleet to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/gke_hub_fleet google_gke_hub_fleet} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GkeHubFleetConfig = {}
    */
    constructor(scope: Construct, id: string, config?: GkeHubFleetConfig);
    get createTime(): string;
    get deleteTime(): string;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _state;
    get state(): GkeHubFleetStateList;
    get uid(): string;
    get updateTime(): string;
    private _defaultClusterConfig;
    get defaultClusterConfig(): GkeHubFleetDefaultClusterConfigOutputReference;
    putDefaultClusterConfig(value: GkeHubFleetDefaultClusterConfig): void;
    resetDefaultClusterConfig(): void;
    get defaultClusterConfigInput(): GkeHubFleetDefaultClusterConfig | undefined;
    private _timeouts;
    get timeouts(): GkeHubFleetTimeoutsOutputReference;
    putTimeouts(value: GkeHubFleetTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GkeHubFleetTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
