/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface IapTunnelIamBindingConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/iap_tunnel_iam_binding#id IapTunnelIamBinding#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/iap_tunnel_iam_binding#members IapTunnelIamBinding#members}
    */
    readonly members: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/iap_tunnel_iam_binding#project IapTunnelIamBinding#project}
    */
    readonly project?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/iap_tunnel_iam_binding#role IapTunnelIamBinding#role}
    */
    readonly role: string;
    /**
    * condition block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/iap_tunnel_iam_binding#condition IapTunnelIamBinding#condition}
    */
    readonly condition?: IapTunnelIamBindingCondition;
}
export interface IapTunnelIamBindingCondition {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/iap_tunnel_iam_binding#description IapTunnelIamBinding#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/iap_tunnel_iam_binding#expression IapTunnelIamBinding#expression}
    */
    readonly expression: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/iap_tunnel_iam_binding#title IapTunnelIamBinding#title}
    */
    readonly title: string;
}
export declare function iapTunnelIamBindingConditionToTerraform(struct?: IapTunnelIamBindingConditionOutputReference | IapTunnelIamBindingCondition): any;
export declare function iapTunnelIamBindingConditionToHclTerraform(struct?: IapTunnelIamBindingConditionOutputReference | IapTunnelIamBindingCondition): any;
export declare class IapTunnelIamBindingConditionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): IapTunnelIamBindingCondition | undefined;
    set internalValue(value: IapTunnelIamBindingCondition | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _expression?;
    get expression(): string;
    set expression(value: string);
    get expressionInput(): string | undefined;
    private _title?;
    get title(): string;
    set title(value: string);
    get titleInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/iap_tunnel_iam_binding google_iap_tunnel_iam_binding}
*/
export declare class IapTunnelIamBinding extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_iap_tunnel_iam_binding";
    /**
    * Generates CDKTF code for importing a IapTunnelIamBinding resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the IapTunnelIamBinding to import
    * @param importFromId The id of the existing IapTunnelIamBinding that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/iap_tunnel_iam_binding#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the IapTunnelIamBinding to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/iap_tunnel_iam_binding google_iap_tunnel_iam_binding} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options IapTunnelIamBindingConfig
    */
    constructor(scope: Construct, id: string, config: IapTunnelIamBindingConfig);
    get etag(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _members?;
    get members(): string[];
    set members(value: string[]);
    get membersInput(): string[] | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _role?;
    get role(): string;
    set role(value: string);
    get roleInput(): string | undefined;
    private _condition;
    get condition(): IapTunnelIamBindingConditionOutputReference;
    putCondition(value: IapTunnelIamBindingCondition): void;
    resetCondition(): void;
    get conditionInput(): IapTunnelIamBindingCondition | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
