/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NetworkConnectivitySpokeConfig extends cdktf.TerraformMetaArguments {
    /**
    * An optional description of the spoke.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#description NetworkConnectivitySpoke#description}
    */
    readonly description?: string;
    /**
    * Immutable. The URI of the hub that this spoke is attached to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#hub NetworkConnectivitySpoke#hub}
    */
    readonly hub: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#id NetworkConnectivitySpoke#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Optional labels in key:value format. For more information about labels, see [Requirements for labels](https://cloud.google.com/resource-manager/docs/creating-managing-labels#requirements).
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field `effective_labels` for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#labels NetworkConnectivitySpoke#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The location for the resource
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#location NetworkConnectivitySpoke#location}
    */
    readonly location: string;
    /**
    * Immutable. The name of the spoke. Spoke names must be unique.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#name NetworkConnectivitySpoke#name}
    */
    readonly name: string;
    /**
    * The project for the resource
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#project NetworkConnectivitySpoke#project}
    */
    readonly project?: string;
    /**
    * linked_interconnect_attachments block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#linked_interconnect_attachments NetworkConnectivitySpoke#linked_interconnect_attachments}
    */
    readonly linkedInterconnectAttachments?: NetworkConnectivitySpokeLinkedInterconnectAttachments;
    /**
    * linked_router_appliance_instances block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#linked_router_appliance_instances NetworkConnectivitySpoke#linked_router_appliance_instances}
    */
    readonly linkedRouterApplianceInstances?: NetworkConnectivitySpokeLinkedRouterApplianceInstances;
    /**
    * linked_vpc_network block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#linked_vpc_network NetworkConnectivitySpoke#linked_vpc_network}
    */
    readonly linkedVpcNetwork?: NetworkConnectivitySpokeLinkedVpcNetwork;
    /**
    * linked_vpn_tunnels block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#linked_vpn_tunnels NetworkConnectivitySpoke#linked_vpn_tunnels}
    */
    readonly linkedVpnTunnels?: NetworkConnectivitySpokeLinkedVpnTunnels;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#timeouts NetworkConnectivitySpoke#timeouts}
    */
    readonly timeouts?: NetworkConnectivitySpokeTimeouts;
}
export interface NetworkConnectivitySpokeLinkedInterconnectAttachments {
    /**
    * A value that controls whether site-to-site data transfer is enabled for these resources. Note that data transfer is available only in supported locations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#site_to_site_data_transfer NetworkConnectivitySpoke#site_to_site_data_transfer}
    */
    readonly siteToSiteDataTransfer: boolean | cdktf.IResolvable;
    /**
    * The URIs of linked interconnect attachment resources
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#uris NetworkConnectivitySpoke#uris}
    */
    readonly uris: string[];
}
export declare function networkConnectivitySpokeLinkedInterconnectAttachmentsToTerraform(struct?: NetworkConnectivitySpokeLinkedInterconnectAttachmentsOutputReference | NetworkConnectivitySpokeLinkedInterconnectAttachments): any;
export declare function networkConnectivitySpokeLinkedInterconnectAttachmentsToHclTerraform(struct?: NetworkConnectivitySpokeLinkedInterconnectAttachmentsOutputReference | NetworkConnectivitySpokeLinkedInterconnectAttachments): any;
export declare class NetworkConnectivitySpokeLinkedInterconnectAttachmentsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NetworkConnectivitySpokeLinkedInterconnectAttachments | undefined;
    set internalValue(value: NetworkConnectivitySpokeLinkedInterconnectAttachments | undefined);
    private _siteToSiteDataTransfer?;
    get siteToSiteDataTransfer(): boolean | cdktf.IResolvable;
    set siteToSiteDataTransfer(value: boolean | cdktf.IResolvable);
    get siteToSiteDataTransferInput(): boolean | cdktf.IResolvable | undefined;
    private _uris?;
    get uris(): string[];
    set uris(value: string[]);
    get urisInput(): string[] | undefined;
}
export interface NetworkConnectivitySpokeLinkedRouterApplianceInstancesInstances {
    /**
    * The IP address on the VM to use for peering.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#ip_address NetworkConnectivitySpoke#ip_address}
    */
    readonly ipAddress?: string;
    /**
    * The URI of the virtual machine resource
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#virtual_machine NetworkConnectivitySpoke#virtual_machine}
    */
    readonly virtualMachine?: string;
}
export declare function networkConnectivitySpokeLinkedRouterApplianceInstancesInstancesToTerraform(struct?: NetworkConnectivitySpokeLinkedRouterApplianceInstancesInstances | cdktf.IResolvable): any;
export declare function networkConnectivitySpokeLinkedRouterApplianceInstancesInstancesToHclTerraform(struct?: NetworkConnectivitySpokeLinkedRouterApplianceInstancesInstances | cdktf.IResolvable): any;
export declare class NetworkConnectivitySpokeLinkedRouterApplianceInstancesInstancesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NetworkConnectivitySpokeLinkedRouterApplianceInstancesInstances | cdktf.IResolvable | undefined;
    set internalValue(value: NetworkConnectivitySpokeLinkedRouterApplianceInstancesInstances | cdktf.IResolvable | undefined);
    private _ipAddress?;
    get ipAddress(): string;
    set ipAddress(value: string);
    resetIpAddress(): void;
    get ipAddressInput(): string | undefined;
    private _virtualMachine?;
    get virtualMachine(): string;
    set virtualMachine(value: string);
    resetVirtualMachine(): void;
    get virtualMachineInput(): string | undefined;
}
export declare class NetworkConnectivitySpokeLinkedRouterApplianceInstancesInstancesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NetworkConnectivitySpokeLinkedRouterApplianceInstancesInstances[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NetworkConnectivitySpokeLinkedRouterApplianceInstancesInstancesOutputReference;
}
export interface NetworkConnectivitySpokeLinkedRouterApplianceInstances {
    /**
    * A value that controls whether site-to-site data transfer is enabled for these resources. Note that data transfer is available only in supported locations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#site_to_site_data_transfer NetworkConnectivitySpoke#site_to_site_data_transfer}
    */
    readonly siteToSiteDataTransfer: boolean | cdktf.IResolvable;
    /**
    * instances block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#instances NetworkConnectivitySpoke#instances}
    */
    readonly instances: NetworkConnectivitySpokeLinkedRouterApplianceInstancesInstances[] | cdktf.IResolvable;
}
export declare function networkConnectivitySpokeLinkedRouterApplianceInstancesToTerraform(struct?: NetworkConnectivitySpokeLinkedRouterApplianceInstancesOutputReference | NetworkConnectivitySpokeLinkedRouterApplianceInstances): any;
export declare function networkConnectivitySpokeLinkedRouterApplianceInstancesToHclTerraform(struct?: NetworkConnectivitySpokeLinkedRouterApplianceInstancesOutputReference | NetworkConnectivitySpokeLinkedRouterApplianceInstances): any;
export declare class NetworkConnectivitySpokeLinkedRouterApplianceInstancesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NetworkConnectivitySpokeLinkedRouterApplianceInstances | undefined;
    set internalValue(value: NetworkConnectivitySpokeLinkedRouterApplianceInstances | undefined);
    private _siteToSiteDataTransfer?;
    get siteToSiteDataTransfer(): boolean | cdktf.IResolvable;
    set siteToSiteDataTransfer(value: boolean | cdktf.IResolvable);
    get siteToSiteDataTransferInput(): boolean | cdktf.IResolvable | undefined;
    private _instances;
    get instances(): NetworkConnectivitySpokeLinkedRouterApplianceInstancesInstancesList;
    putInstances(value: NetworkConnectivitySpokeLinkedRouterApplianceInstancesInstances[] | cdktf.IResolvable): void;
    get instancesInput(): cdktf.IResolvable | NetworkConnectivitySpokeLinkedRouterApplianceInstancesInstances[] | undefined;
}
export interface NetworkConnectivitySpokeLinkedVpcNetwork {
    /**
    * IP ranges encompassing the subnets to be excluded from peering.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#exclude_export_ranges NetworkConnectivitySpoke#exclude_export_ranges}
    */
    readonly excludeExportRanges?: string[];
    /**
    * The URI of the VPC network resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#uri NetworkConnectivitySpoke#uri}
    */
    readonly uri: string;
}
export declare function networkConnectivitySpokeLinkedVpcNetworkToTerraform(struct?: NetworkConnectivitySpokeLinkedVpcNetworkOutputReference | NetworkConnectivitySpokeLinkedVpcNetwork): any;
export declare function networkConnectivitySpokeLinkedVpcNetworkToHclTerraform(struct?: NetworkConnectivitySpokeLinkedVpcNetworkOutputReference | NetworkConnectivitySpokeLinkedVpcNetwork): any;
export declare class NetworkConnectivitySpokeLinkedVpcNetworkOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NetworkConnectivitySpokeLinkedVpcNetwork | undefined;
    set internalValue(value: NetworkConnectivitySpokeLinkedVpcNetwork | undefined);
    private _excludeExportRanges?;
    get excludeExportRanges(): string[];
    set excludeExportRanges(value: string[]);
    resetExcludeExportRanges(): void;
    get excludeExportRangesInput(): string[] | undefined;
    private _uri?;
    get uri(): string;
    set uri(value: string);
    get uriInput(): string | undefined;
}
export interface NetworkConnectivitySpokeLinkedVpnTunnels {
    /**
    * A value that controls whether site-to-site data transfer is enabled for these resources. Note that data transfer is available only in supported locations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#site_to_site_data_transfer NetworkConnectivitySpoke#site_to_site_data_transfer}
    */
    readonly siteToSiteDataTransfer: boolean | cdktf.IResolvable;
    /**
    * The URIs of linked VPN tunnel resources.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#uris NetworkConnectivitySpoke#uris}
    */
    readonly uris: string[];
}
export declare function networkConnectivitySpokeLinkedVpnTunnelsToTerraform(struct?: NetworkConnectivitySpokeLinkedVpnTunnelsOutputReference | NetworkConnectivitySpokeLinkedVpnTunnels): any;
export declare function networkConnectivitySpokeLinkedVpnTunnelsToHclTerraform(struct?: NetworkConnectivitySpokeLinkedVpnTunnelsOutputReference | NetworkConnectivitySpokeLinkedVpnTunnels): any;
export declare class NetworkConnectivitySpokeLinkedVpnTunnelsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NetworkConnectivitySpokeLinkedVpnTunnels | undefined;
    set internalValue(value: NetworkConnectivitySpokeLinkedVpnTunnels | undefined);
    private _siteToSiteDataTransfer?;
    get siteToSiteDataTransfer(): boolean | cdktf.IResolvable;
    set siteToSiteDataTransfer(value: boolean | cdktf.IResolvable);
    get siteToSiteDataTransferInput(): boolean | cdktf.IResolvable | undefined;
    private _uris?;
    get uris(): string[];
    set uris(value: string[]);
    get urisInput(): string[] | undefined;
}
export interface NetworkConnectivitySpokeTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#create NetworkConnectivitySpoke#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#delete NetworkConnectivitySpoke#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#update NetworkConnectivitySpoke#update}
    */
    readonly update?: string;
}
export declare function networkConnectivitySpokeTimeoutsToTerraform(struct?: NetworkConnectivitySpokeTimeouts | cdktf.IResolvable): any;
export declare function networkConnectivitySpokeTimeoutsToHclTerraform(struct?: NetworkConnectivitySpokeTimeouts | cdktf.IResolvable): any;
export declare class NetworkConnectivitySpokeTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NetworkConnectivitySpokeTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: NetworkConnectivitySpokeTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke google_network_connectivity_spoke}
*/
export declare class NetworkConnectivitySpoke extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_network_connectivity_spoke";
    /**
    * Generates CDKTF code for importing a NetworkConnectivitySpoke resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NetworkConnectivitySpoke to import
    * @param importFromId The id of the existing NetworkConnectivitySpoke that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NetworkConnectivitySpoke to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/5.31.1/docs/resources/network_connectivity_spoke google_network_connectivity_spoke} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NetworkConnectivitySpokeConfig
    */
    constructor(scope: Construct, id: string, config: NetworkConnectivitySpokeConfig);
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _hub?;
    get hub(): string;
    set hub(value: string);
    get hubInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get state(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get uniqueId(): string;
    get updateTime(): string;
    private _linkedInterconnectAttachments;
    get linkedInterconnectAttachments(): NetworkConnectivitySpokeLinkedInterconnectAttachmentsOutputReference;
    putLinkedInterconnectAttachments(value: NetworkConnectivitySpokeLinkedInterconnectAttachments): void;
    resetLinkedInterconnectAttachments(): void;
    get linkedInterconnectAttachmentsInput(): NetworkConnectivitySpokeLinkedInterconnectAttachments | undefined;
    private _linkedRouterApplianceInstances;
    get linkedRouterApplianceInstances(): NetworkConnectivitySpokeLinkedRouterApplianceInstancesOutputReference;
    putLinkedRouterApplianceInstances(value: NetworkConnectivitySpokeLinkedRouterApplianceInstances): void;
    resetLinkedRouterApplianceInstances(): void;
    get linkedRouterApplianceInstancesInput(): NetworkConnectivitySpokeLinkedRouterApplianceInstances | undefined;
    private _linkedVpcNetwork;
    get linkedVpcNetwork(): NetworkConnectivitySpokeLinkedVpcNetworkOutputReference;
    putLinkedVpcNetwork(value: NetworkConnectivitySpokeLinkedVpcNetwork): void;
    resetLinkedVpcNetwork(): void;
    get linkedVpcNetworkInput(): NetworkConnectivitySpokeLinkedVpcNetwork | undefined;
    private _linkedVpnTunnels;
    get linkedVpnTunnels(): NetworkConnectivitySpokeLinkedVpnTunnelsOutputReference;
    putLinkedVpnTunnels(value: NetworkConnectivitySpokeLinkedVpnTunnels): void;
    resetLinkedVpnTunnels(): void;
    get linkedVpnTunnelsInput(): NetworkConnectivitySpokeLinkedVpnTunnels | undefined;
    private _timeouts;
    get timeouts(): NetworkConnectivitySpokeTimeoutsOutputReference;
    putTimeouts(value: NetworkConnectivitySpokeTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | NetworkConnectivitySpokeTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
